<?php
/**
 * Mismo functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Mismo
 */



if ( ! defined( 'mismo_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	$mismo_blog_theme_info = wp_get_theme();
	define( 'mismo_VERSION', $mismo_blog_theme_info->get( 'Version' ) );
}


if ( ! function_exists( 'mismo_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function mismo_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Mismo, use a find and replace
		 * to change 'mismo' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'mismo', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Enable support for Post Formats on posts.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support( 'post-formats', array(
			'audio',
			'video',
			'gallery'
		) );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' 		=> esc_html__( 'Primary', 'mismo' ),
			'menu-footer' 	=> esc_html__( 'Footer', 'mismo' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'mismo_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'mismo_setup' );

/**
 * Set the theme version, based on theme stylesheet.
 *
 * @global string $mismo_theme_version
 */
function mismo_theme_version_info() {
	$mismo_theme_info = wp_get_theme();
	$GLOBALS['mismo_theme_version'] = $mismo_theme_info->get( 'Version' );
}
add_action( 'after_setup_theme', 'mismo_theme_version_info', 5 );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function mismo_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'mismo_content_width', 640 );
}
add_action( 'after_setup_theme', 'mismo_content_width', 0 );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

 // Load widget function
 require get_template_directory().'/inc/widgets/m-widgets-functions.php';

/**
 * Load theme hook file
 */
require get_template_directory() . '/inc/custom-hooks/m-header-hooks.php';
require get_template_directory() . '/inc/custom-hooks/m-footer-hooks.php';

/**
 * Custom files for custom metabox
 */
require get_template_directory() . '/inc/metaboxes/m-post-metabox.php';

/**
 * Load breadcrumbs class
 */
if ( ! function_exists( 'breadcrumb_trail' ) ) {
	require get_template_directory() . '/inc/mt-class-breadcrumbs.php';
}

/**
 * Load theme settings page
 */
//require get_template_directory(). '/inc/theme-settings/mt-theme-settings.php';

/**
 * Load TGM
 *
 *require get_template_directory() . '/inc/tgm/mt-recommend-plugins.php';
 * /

/**
* Load theme dashboard
*/
require get_template_directory() . '/inc/admin/class-mismo-admin.php';
require get_template_directory() . '/inc/admin/class-mismo-notice.php';
require get_template_directory() . '/inc/admin/class-mismo-dashboard.php';